@@ -24,6 +24,30 @@ test_that("translate sql server -> Oracle DATEDIFF", {
     sql,
     "SELECT CEIL(CAST(drug_era_end_date AS DATE) - CAST(drug_era_start_date AS DATE)) FROM drug_era;"
   )
+  
+  sql <- translate("SELECT DATEDIFF(second,drug_era_start_date,drug_era_end_date) FROM drug_era;",
+    targetDialect = "oracle"
+  )
+  expect_equal_ignore_spaces(
+    sql,
+    "SELECT EXTRACT(SECOND FROM (drug_era_end_date - drug_era_start_date)) FROM drug_era;"
+  )
+  
+  sql <- translate("SELECT DATEDIFF(minute,drug_era_start_date,drug_era_end_date) FROM drug_era;",
+    targetDialect = "oracle"
+  )
+  expect_equal_ignore_spaces(
+    sql,
+    "SELECT EXTRACT(MINUTE FROM (drug_era_end_date - drug_era_start_date)) FROM drug_era;"
+  )
+  
+  sql <- translate("SELECT DATEDIFF(hour,drug_era_start_date,drug_era_end_date) FROM drug_era;",
+    targetDialect = "oracle"
+  )
+  expect_equal_ignore_spaces(
+    sql,
+    "SELECT EXTRACT(HOUR FROM (drug_era_end_date - drug_era_start_date)) FROM drug_era;"
+  )
 })
 
 test_that("translate sql server -> Oracle DATEDIFF year", {
