@@ -226,6 +226,14 @@ test_that("translate sql server -> RedShift DATEADD hh", {
     sql,
     "SELECT DATEADD(hour, CAST(3 as int), drug_era_end_date) FROM drug_era;"
   )
+  
+  sql <- translate("SELECT DATEADD(hour, 3, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(
+    sql,
+    "SELECT DATEADD(hour, CAST(3 as int), drug_era_end_date) FROM drug_era;"
+  )
 })
 
 test_that("translate sql server -> RedShift DATEADD mi", {
@@ -236,6 +244,14 @@ test_that("translate sql server -> RedShift DATEADD mi", {
     sql,
     "SELECT DATEADD(minute, CAST(3 as int), drug_era_end_date) FROM drug_era;"
   )
+  
+  sql <- translate("SELECT DATEADD(minute, 3, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(
+    sql,
+    "SELECT DATEADD(minute, CAST(3 as int), drug_era_end_date) FROM drug_era;"
+  )
 })
 
 test_that("translate sql server -> RedShift DATEADD ss", {
@@ -246,6 +262,14 @@ test_that("translate sql server -> RedShift DATEADD ss", {
     sql,
     "SELECT DATEADD(second, CAST(3 as int), drug_era_end_date) FROM drug_era;"
   )
+  
+  sql <- translate("SELECT DATEADD(second, 3, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(
+    sql,
+    "SELECT DATEADD(second, CAST(3 as int), drug_era_end_date) FROM drug_era;"
+  )
 })
 
 test_that("translate sql server -> RedShift DATEADD mcs", {
@@ -367,6 +391,14 @@ test_that("translate sql server -> RedShift DATEDIFF hh", {
     sql,
     "SELECT DATEDIFF(hour, drug_era_start_date, drug_era_end_date) FROM drug_era;"
   )
+  
+  sql <- translate("SELECT DATEDIFF(hour, drug_era_start_date, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(
+    sql,
+    "SELECT DATEDIFF(hour, drug_era_start_date, drug_era_end_date) FROM drug_era;"
+  )
 })
 
 test_that("translate sql server -> RedShift DATEDIFF mi", {
@@ -377,6 +409,14 @@ test_that("translate sql server -> RedShift DATEDIFF mi", {
     sql,
     "SELECT DATEDIFF(minute, drug_era_start_date, drug_era_end_date) FROM drug_era;"
   )
+  
+  sql <- translate("SELECT DATEDIFF(minute, drug_era_start_date, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(
+    sql,
+    "SELECT DATEDIFF(minute, drug_era_start_date, drug_era_end_date) FROM drug_era;"
+  )
 })
 
 test_that("translate sql server -> RedShift DATEDIFF n", {
@@ -397,6 +437,14 @@ test_that("translate sql server -> RedShift DATEDIFF ss", {
     sql,
     "SELECT DATEDIFF(second, drug_era_start_date, drug_era_end_date) FROM drug_era;"
   )
+  
+  sql <- translate("SELECT DATEDIFF(second, drug_era_start_date, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(
+    sql,
+    "SELECT DATEDIFF(second, drug_era_start_date, drug_era_end_date) FROM drug_era;"
+  )
 })
 
 test_that("translate sql server -> RedShift DATEDIFF mcs", {
@@ -554,6 +602,11 @@ test_that("translate sql server -> RedShift DATEPART dd", {
     targetDialect = "redshift"
   )
   expect_equal_ignore_spaces(sql, "SELECT DATEPART(day, drug_era_end_date) FROM drug_era;")
+  
+  sql <- translate("SELECT DATEPART(day, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(sql, "SELECT DATEPART(day, drug_era_end_date) FROM drug_era;")
 })
 
 test_that("translate sql server -> RedShift DATEPART m", {
@@ -617,6 +670,11 @@ test_that("translate sql server -> RedShift DATEPART hh", {
     targetDialect = "redshift"
   )
   expect_equal_ignore_spaces(sql, "SELECT DATEPART(hour, drug_era_end_date) FROM drug_era;")
+  
+  sql <- translate("SELECT DATEPART(hour, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(sql, "SELECT DATEPART(hour, drug_era_end_date) FROM drug_era;")
 })
 
 test_that("translate sql server -> RedShift DATEPART mi", {
@@ -624,6 +682,11 @@ test_that("translate sql server -> RedShift DATEPART mi", {
     targetDialect = "redshift"
   )
   expect_equal_ignore_spaces(sql, "SELECT DATEPART(minute, drug_era_end_date) FROM drug_era;")
+  
+  sql <- translate("SELECT DATEPART(minute, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(sql, "SELECT DATEPART(minute, drug_era_end_date) FROM drug_era;")
 })
 
 test_that("translate sql server -> RedShift DATEPART n", {
@@ -638,6 +701,11 @@ test_that("translate sql server -> RedShift DATEPART ss", {
     targetDialect = "redshift"
   )
   expect_equal_ignore_spaces(sql, "SELECT DATEPART(second, drug_era_end_date) FROM drug_era;")
+  
+  sql <- translate("SELECT DATEPART(second, drug_era_end_date) FROM drug_era;",
+    targetDialect = "redshift"
+  )
+  expect_equal_ignore_spaces(sql, "SELECT DATEPART(second, drug_era_end_date) FROM drug_era;")
 })
 
 test_that("translate sql server -> RedShift DATEPART mcs", {
